{#
  Copyright (C) 2020 CERN.

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends admin_base_template %}
